#
# spec file for package python-django-rq
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-rq
Version:        2.10.2
Release:        1.1
Summary:        Simple app that provides django integration for RQ (Redis Queue)
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/rq/django-rq
Source:         https://github.com/rq/django-rq/archive/v%{version}/django-rq-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.0
Requires:       python-rq >= 1.14
Recommends:     python-django-redis >= 3.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.0}
BuildRequires:  %{python_module django-redis >= 3.0}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module rq >= 1.14}
BuildRequires:  %{python_module rq-scheduler}
BuildRequires:  redis
# /SECTION
%python_subpackages

%description
Django integration with RQ, a Redis based Python queuing library.
Django-RQ is a simple app that allows you to configure your queues
in django's settings.py and easily use them in your project.

%prep
%setup -q -n django-rq-%{version}

%build
%python_build

%install
%python_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/django_rq/tests/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{_sbindir}/redis-server &
export PYTHONPATH=${PWD}
export DJANGO_SETTINGS_MODULE=django_rq.tests.settings
%pytest -k 'not (test_job_details or test_jobs)'

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/django[-_]rq*/

%changelog
* Fri May  3 2024 Dirk Müller <dmueller@suse.com>
- update to 2.10.2:
  * Added support for Django 5.0. Thanks @selwin!
  * Fixed an error in Python 3.12. Thanks @selwin!
  * Fixes an issue that may happen if Redis port is not
    specified. Thanks @terencehonles!
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 2.10.1:
  * Fixed packaging issues with 2.10.0.
  * Added `rqworker-pool` management command.
  * Compatibility with Django 5.0.
  * The scheduler now defaults to db 0.
* Wed Dec  6 2023 Dirk Müller <dmueller@suse.com>
- update to 2.9.0:
  * Added an option to delete all failed jobs.
  * You can now specify `SERIALIZER` option while declaring
    queues in `settings.py`
  * Updated templates to match newer versions of Django admin's
    styling.
  * Don't show `Empty Queue` button on registry pages.
* Sat May 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.8.1:
  * Added a button to stop currently running jobs.
  * Added a failed jobs column to rqstats command.
  * Explicitly requires RQ >= 1.14 in `setup.py`.
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 2.8.0:
  * Support for RQ 1.14.
  * Show scheduler PID information in admin interface.
  * Added `serializer` argument to `rqworker` command.
  * Added `USERNAME` and `SENTINEL_KWARGS` support.
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 2.7.0:
  * Able to show multiple execution results for each job
    (requires RQ v1.12).
  * Various admin interface improvements.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to v2.6.0:
  * Added --max-jobs argument to rqworker management command.
  * Remove job from ScheduledJobRegistry if a scheduled job is enqueued from
    admin. Thanks @robertaistleitner!
* Tue Oct 11 2022 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Tidy spec
* Tue Apr 12 2022 Misha Komarovskiy <zombah@gmail.com>
- Update to 2.5.1
  * Redis.from_url does not accept ssl_cert_reqs argument for
    non SSL Redis URL. Thanks @barash-asenov!
* Mon Aug 30 2021 Misha Komarovskiy <zombah@gmail.com>
- update to 2.4.1
* Thu May 14 2020 Misha Komarovskiy <zombah@gmail.com>
- update to 2.3.2
  - Support for RQ >= 1.4.0
* Thu Apr 23 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.3.1
  - Added `--with-scheduler` argument to `rqworker` management
    command. Thanks @stlk!
  - Fixed a bug where opening job detail would crash if
    job.dependency no longer exists. Thanks @selwin!
  - Support for RQ's new `ScheduledJobRegistry`. Thanks @Yolley!
  - Improve performance when displaying pages showing a large
    number of jobs by using `Job.fetch_many()`. Thanks @selwin!
  - `django-rq` will now automatically cleanup orphaned worker keys
    in job registries. Thanks @selwin!
  - Site name now properly displayed in Django-RQ admin pages.
    Thanks @tom-price!
  - `NoSuchJobError`s are now handled properly when requeuing all
    jobs. Thanks @thomasmatecki!
  - Support for displaying jobs with names containing `$`. Thanks
    @gowthamk63!
* Sat Jan 18 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.2.0
  - Support for Django 3.0. This release also drops support for
    Django 1.X. Thanks @hugorodgerbrown!
  - `rqworker` management command now properly passes in
    `--verbosity` to `Worker`. Thanks @stlk!
  - The admin interface can now view jobs with `:` on their IDs.
    Thanks @carboncoop!
  - Job detail page now shows `job.dependency`. Thanks @selwin!
* Sat Sep 28 2019 ecsos@opensuse.org
- Initial version
